#! /bin/bash  
#
# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is the Netscape security libraries.
#
# The Initial Developer of the Original Code is
# Netscape Communications Corporation.
# Portions created by the Initial Developer are Copyright (C) 1994-2009
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   Hanno Boeck <hanno@hboeck.de>
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****

########################################################################
#
# mozilla/security/nss/tests/pss/pss.sh
#
# Script to test NSS RSA-PSS certificates
#
########################################################################

############################## pss_init ################################
# local shell function to initialize this script
########################################################################
pss_init()
{
  mydir=`pwd`

  SCRIPTNAME=pss.sh      # sourced - $0 would point to all.sh

  if [ -z "${INIT_SOURCED}" -o "${INIT_SOURCED}" != "TRUE" ]; then
      cd ../common
      . ./init.sh
  fi

  html_head "RSA-PSS Tests"

  PSSDIR="${HOSTDIR}/pss"
  mkdir -p "${PSSDIR}"
}

############################## pss_main ################################
# local shell function to run the tests
########################################################################
pss_main()
{
pwd
  for i in ${mydir}/goodsamples/*; do
    ${BINDIR}/vfychain -pp -t -a $i
    html_msg $? 0 Verifying known-good certificate $i
  done
  for i in ${mydir}/badsamples/*; do
    ${BINDIR}/vfychain -pp -t -a $i
    html_msg $? 1 Verifying known-bad certificate $i
  done
  echo "eiCh0Goo" > ${PSSDIR}/password.txt
  echo -e "y\n\n" > ${PSSDIR}/input
  ${BINDIR}/certutil -N -d ${PSSDIR} -f ${PSSDIR}/password.txt
  echo ${BINDIR}/certutil -S --pss default -2 -d ${PSSDIR} -v 9999 -g 2048 -n pss1 -s "cn=pss1" -x -t "C" -z ${NOISE_FILE} -f ${PSSDIR}/password.txt
  ${BINDIR}/certutil -S --pss default -d ${PSSDIR} -2 -v 9999 -g 2048 -n pss1 -s "cn=pss1" -x -t "C" -z ${NOISE_FILE} -f ${PSSDIR}/password.txt < ${PSSDIR}/input
  ${BINDIR}/certutil -S -Z SHA256 --pss MGF1:SHA384:0 -d ${PSSDIR} -2 -v 9999 -g 2048 -n pss2 -s "cn=pss2" -x -t "C" -z ${NOISE_FILE} -f ${PSSDIR}/password.txt < ${PSSDIR}/input
  ${BINDIR}/certutil -S -Z SHA512 --pss MGF1:SHA1:50 -d ${PSSDIR} -2 -v 9999 -g 2048 -n pss3 -s "cn=pss3" -x -t "C" -z ${NOISE_FILE} -f ${PSSDIR}/password.txt < ${PSSDIR}/input

  for i in 1 2 3; do
      ${BINDIR}/certutil -L -d ${PSSDIR} -n pss$i -a > ${PSSDIR}/pss$i.crt
      ${BINDIR}/vfychain -pp -t -a ${PSSDIR}/pss$i.crt
      html_msg $? 0 Verifying self created certificate $i
  done

}
  
############################## pss_cleanup ############################
# local shell function to finish this script (no exit since it might be
# sourced)
########################################################################
pss_cleanup()
{
  html "</TABLE><BR>"
  cd ${QADIR}
  . common/cleanup.sh
}

################## main #################################################

pss_init
pss_main
pss_cleanup
